package go_swagger

import (
	"os"

	"github.com/juju/errors"

	"git.home.m-and-m.ovh/mderasse/gouick/helpers"
	"git.home.m-and-m.ovh/mderasse/gouick/helpers/models"

	log "github.com/sirupsen/logrus"
)

// GetInitializeUserInput will ask user to provide information that allow initialization of a project.
func (a APIType) GetInitializeUserInput(params *models.UserInputParams) (*models.UserInputParams, error) {

	log.Debugf("Starting %s user input", a.GetName())

	// Get current path
	log.Debug("Getting current location")

	currentPath, err := os.Getwd()
	if err != nil {
		log.Errorf("Fail to get current path. The following error happen: %s", err.Error())
		return nil, errors.Trace(err)
	}

	// Check if we are in gopath
	log.Debug("Checking if we are in GoPath")

	isInGoPath := helpers.IsInGoPath(currentPath)
	if !isInGoPath {

		log.Debug("We are not in GoPath, ask extra info")
		goModulePath := helpers.StringInput()
		log.Info("Go Module name:")
		params.GoModuleName = &goModulePath
	}

	log.Info("Do you want to enable database integration ?")
	params.DB = helpers.YesOrNoInput()

	return params, nil
}
